@@ -6,6 +6,7 @@ use super::{Context, Module, RootModuleConfig};
 use crate::configs::git_status::GitStatusConfig;
 use crate::formatter::StringFormatter;
 use crate::segment::Segment;
+use std::ffi::OsStr;
 use std::sync::Arc;
 
 const ALL_STATUS_FORMAT: &str = "$conflicted$stashed$deleted$renamed$modified$staged$untracked";
@@ -18,6 +19,7 @@ const ALL_STATUS_FORMAT: &str = "$conflicted$stashed$deleted$renamed$modified$st
 ///   - `⇡` – This branch is ahead of the branch being tracked
 ///   - `⇣` – This branch is behind of the branch being tracked
 ///   - `⇕` – This branch has diverged from the branch being tracked
+///   - `` – This branch is up-to-date with the branch being tracked
 ///   - `?` — There are untracked files in the working directory
 ///   - `$` — A stash exists for the local repository
 ///   - `!` — There are file modifications in the working directory
@@ -30,6 +32,9 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
     let mut module = context.new_module("git_status");
     let config: GitStatusConfig = GitStatusConfig::try_load(module.config);
 
+    //Return None if not in git repository
+    context.get_repo().ok()?;
+
     let parsed = StringFormatter::new(config.format).and_then(|formatter| {
         formatter
             .map_meta(|variable, _| match variable {
@@ -47,6 +52,7 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
                         format_count(config.stashed, "git_status.stashed", count)
                     }),
                     "ahead_behind" => info.get_ahead_behind().and_then(|(ahead, behind)| {
+                        let (ahead, behind) = (ahead?, behind?);
                         if ahead > 0 && behind > 0 {
                             format_text(config.diverged, "git_status.diverged", |variable| {
                                 match variable {
@@ -60,7 +66,7 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
                         } else if behind > 0 && ahead == 0 {
                             format_count(config.behind, "git_status.behind", behind)
                         } else {
-                            None
+                            format_symbol(config.up_to_date, "git_status.up_to_date")
                         }
                     }),
                     "conflicted" => info.get_conflicted().and_then(|count| {
@@ -120,7 +126,7 @@ impl<'a> GitStatusInfo<'a> {
         }
     }
 
-    pub fn get_ahead_behind(&self) -> Option<(usize, usize)> {
+    pub fn get_ahead_behind(&self) -> Option<(Option<usize>, Option<usize>)> {
         self.get_repo_status().map(|data| (data.ahead, data.behind))
     }
 
@@ -179,12 +185,12 @@ fn get_repo_status(context: &Context) -> Option<RepoStatus> {
     let status_output = context.exec_cmd(
         "git",
         &[
-            "-C",
-            &context.current_dir.to_string_lossy(),
-            "--no-optional-locks",
-            "status",
-            "--porcelain=2",
-            "--branch",
+            OsStr::new("-C"),
+            context.current_dir.as_os_str(),
+            OsStr::new("--no-optional-locks"),
+            OsStr::new("status"),
+            OsStr::new("--porcelain=2"),
+            OsStr::new("--branch"),
         ],
     )?;
     let statuses = status_output.stdout.lines();
@@ -204,11 +210,11 @@ fn get_stashed_count(context: &Context) -> Option<usize> {
     let stash_output = context.exec_cmd(
         "git",
         &[
-            "-C",
-            &context.current_dir.to_string_lossy(),
-            "--no-optional-locks",
-            "stash",
-            "list",
+            OsStr::new("-C"),
+            context.current_dir.as_os_str(),
+            OsStr::new("--no-optional-locks"),
+            OsStr::new("stash"),
+            OsStr::new("list"),
         ],
     )?;
 
@@ -217,8 +223,8 @@ fn get_stashed_count(context: &Context) -> Option<usize> {
 
 #[derive(Default, Debug, Copy, Clone)]
 struct RepoStatus {
-    ahead: usize,
-    behind: usize,
+    ahead: Option<usize>,
+    behind: Option<usize>,
     conflicted: usize,
     deleted: usize,
     renamed: usize,
@@ -228,51 +234,56 @@ struct RepoStatus {
 }
 
 impl RepoStatus {
-    fn is_conflicted(status: &str) -> bool {
-        status.starts_with("u ")
-    }
-
-    fn is_deleted(status: &str) -> bool {
+    fn is_deleted(short_status: &str) -> bool {
         // is_wt_deleted || is_index_deleted
-        status.starts_with("1 .D") || status.starts_with("1 D")
+        short_status.contains('D')
     }
 
-    fn is_renamed(status: &str) -> bool {
-        // is_wt_renamed || is_index_renamed
-        // Potentially a copy and not a rename
-        status.starts_with("2 ")
+    fn is_modified(short_status: &str) -> bool {
+        // is_wt_modified || is_wt_added
+        short_status.ends_with('M') || short_status.ends_with('A')
     }
 
-    fn is_modified(status: &str) -> bool {
-        // is_wt_modified
-        status.starts_with("1 .M") || status.starts_with("1 .A")
+    fn is_staged(short_status: &str) -> bool {
+        // is_index_modified || is_index_added
+        short_status.starts_with('M') || short_status.starts_with('A')
     }
 
-    fn is_staged(status: &str) -> bool {
-        // is_index_modified || is_index_new
-        status.starts_with("1 M") || status.starts_with("1 A")
-    }
+    fn parse_normal_status(&mut self, short_status: &str) {
+        if Self::is_deleted(short_status) {
+            self.deleted += 1;
+        }
 
-    fn is_untracked(status: &str) -> bool {
-        // is_wt_new
-        status.starts_with("? ")
+        if Self::is_modified(short_status) {
+            self.modified += 1;
+        }
+
+        if Self::is_staged(short_status) {
+            self.staged += 1;
+        }
     }
 
     fn add(&mut self, s: &str) {
-        self.conflicted += RepoStatus::is_conflicted(s) as usize;
-        self.deleted += RepoStatus::is_deleted(s) as usize;
-        self.renamed += RepoStatus::is_renamed(s) as usize;
-        self.modified += RepoStatus::is_modified(s) as usize;
-        self.staged += RepoStatus::is_staged(s) as usize;
-        self.untracked += RepoStatus::is_untracked(s) as usize;
+        match s.chars().next() {
+            Some('1') => self.parse_normal_status(&s[2..4]),
+            Some('2') => {
+                self.renamed += 1;
+                self.parse_normal_status(&s[2..4])
+            }
+            Some('u') => self.conflicted += 1,
+            Some('?') => self.untracked += 1,
+            Some('!') => (),
+            Some(_) => log::error!("Unknown line type in git status output"),
+            None => log::error!("Missing line type in git status output"),
+        }
     }
 
     fn set_ahead_behind(&mut self, s: &str) {
         let re = Regex::new(r"branch\.ab \+([0-9]+) \-([0-9]+)").unwrap();
 
         if let Some(caps) = re.captures(s) {
-            self.ahead = caps.get(1).unwrap().as_str().parse::<usize>().unwrap();
-            self.behind = caps.get(2).unwrap().as_str().parse::<usize>().unwrap();
+            self.ahead = caps.get(1).unwrap().as_str().parse::<usize>().ok();
+            self.behind = caps.get(2).unwrap().as_str().parse::<usize>().ok();
         }
     }
 }
@@ -303,15 +314,20 @@ fn format_count(format_str: &str, config_path: &str, count: usize) -> Option<Vec
     })
 }
 
+fn format_symbol(format_str: &str, config_path: &str) -> Option<Vec<Segment>> {
+    format_text(format_str, config_path, |_variable| None)
+}
+
 #[cfg(test)]
 mod tests {
     use ansi_term::{ANSIStrings, Color};
+    use std::ffi::OsStr;
     use std::fs::{self, File};
-    use std::io;
+    use std::io::{self, prelude::*};
     use std::path::Path;
-    use std::process::Command;
 
     use crate::test::{fixture_repo, FixtureProvider, ModuleRenderer};
+    use crate::utils::create_command;
 
     /// Right after the calls to git the filesystem state may not have finished
     /// updating yet causing some of the tests to fail. These barriers are placed
@@ -350,7 +366,7 @@ mod tests {
     fn shows_behind() -> io::Result<()> {
         let repo_dir = fixture_repo(FixtureProvider::Git)?;
 
-        behind(&repo_dir.path())?;
+        behind(repo_dir.path())?;
 
         let actual = ModuleRenderer::new("git_status")
             .path(repo_dir.path())
@@ -365,7 +381,7 @@ mod tests {
     fn shows_behind_with_count() -> io::Result<()> {
         let repo_dir = fixture_repo(FixtureProvider::Git)?;
 
-        behind(&repo_dir.path())?;
+        behind(repo_dir.path())?;
 
         let actual = ModuleRenderer::new("git_status")
             .config(toml::toml! {
@@ -385,7 +401,7 @@ mod tests {
         let repo_dir = fixture_repo(FixtureProvider::Git)?;
 
         File::create(repo_dir.path().join("readme.md"))?.sync_all()?;
-        ahead(&repo_dir.path())?;
+        ahead(repo_dir.path())?;
 
         let actual = ModuleRenderer::new("git_status")
             .path(&repo_dir.path())
@@ -401,7 +417,7 @@ mod tests {
         let repo_dir = fixture_repo(FixtureProvider::Git)?;
 
         File::create(repo_dir.path().join("readme.md"))?.sync_all()?;
-        ahead(&repo_dir.path())?;
+        ahead(repo_dir.path())?;
 
         let actual = ModuleRenderer::new("git_status")
             .config(toml::toml! {
@@ -420,7 +436,7 @@ mod tests {
     fn shows_diverged() -> io::Result<()> {
         let repo_dir = fixture_repo(FixtureProvider::Git)?;
 
-        diverge(&repo_dir.path())?;
+        diverge(repo_dir.path())?;
 
         let actual = ModuleRenderer::new("git_status")
             .path(&repo_dir.path())
@@ -435,7 +451,7 @@ mod tests {
     fn shows_diverged_with_count() -> io::Result<()> {
         let repo_dir = fixture_repo(FixtureProvider::Git)?;
 
-        diverge(&repo_dir.path())?;
+        diverge(repo_dir.path())?;
 
         let actual = ModuleRenderer::new("git_status")
             .config(toml::toml! {
@@ -450,11 +466,28 @@ mod tests {
         repo_dir.close()
     }
 
+    #[test]
+    fn shows_up_to_date_with_upstream() -> io::Result<()> {
+        let repo_dir = fixture_repo(FixtureProvider::Git)?;
+
+        let actual = ModuleRenderer::new("git_status")
+            .config(toml::toml! {
+                [git_status]
+                up_to_date="✓"
+            })
+            .path(&repo_dir.path())
+            .collect();
+        let expected = format_output("✓");
+
+        assert_eq!(expected, actual);
+        repo_dir.close()
+    }
+
     #[test]
     fn shows_conflicted() -> io::Result<()> {
         let repo_dir = fixture_repo(FixtureProvider::Git)?;
 
-        create_conflict(&repo_dir.path())?;
+        create_conflict(repo_dir.path())?;
 
         let actual = ModuleRenderer::new("git_status")
             .path(&repo_dir.path())
@@ -469,7 +502,7 @@ mod tests {
     fn shows_conflicted_with_count() -> io::Result<()> {
         let repo_dir = fixture_repo(FixtureProvider::Git)?;
 
-        create_conflict(&repo_dir.path())?;
+        create_conflict(repo_dir.path())?;
 
         let actual = ModuleRenderer::new("git_status")
             .config(toml::toml! {
@@ -488,7 +521,7 @@ mod tests {
     fn shows_untracked_file() -> io::Result<()> {
         let repo_dir = fixture_repo(FixtureProvider::Git)?;
 
-        create_untracked(&repo_dir.path())?;
+        create_untracked(repo_dir.path())?;
 
         let actual = ModuleRenderer::new("git_status")
             .path(&repo_dir.path())
@@ -503,7 +536,7 @@ mod tests {
     fn shows_untracked_file_with_count() -> io::Result<()> {
         let repo_dir = fixture_repo(FixtureProvider::Git)?;
 
-        create_untracked(&repo_dir.path())?;
+        create_untracked(repo_dir.path())?;
 
         let actual = ModuleRenderer::new("git_status")
             .config(toml::toml! {
@@ -522,9 +555,9 @@ mod tests {
     fn doesnt_show_untracked_file_if_disabled() -> io::Result<()> {
         let repo_dir = fixture_repo(FixtureProvider::Git)?;
 
-        create_untracked(&repo_dir.path())?;
+        create_untracked(repo_dir.path())?;
 
-        Command::new("git")
+        create_command("git")?
             .args(&["config", "status.showUntrackedFiles", "no"])
             .current_dir(repo_dir.path())
             .output()?;
@@ -544,9 +577,9 @@ mod tests {
         let repo_dir = fixture_repo(FixtureProvider::Git)?;
         barrier();
 
-        create_stash(&repo_dir.path())?;
+        create_stash(repo_dir.path())?;
 
-        Command::new("git")
+        create_command("git")?
             .args(&["reset", "--hard", "HEAD"])
             .current_dir(repo_dir.path())
             .output()?;
@@ -566,10 +599,10 @@ mod tests {
         let repo_dir = fixture_repo(FixtureProvider::Git)?;
         barrier();
 
-        create_stash(&repo_dir.path())?;
+        create_stash(repo_dir.path())?;
         barrier();
 
-        Command::new("git")
+        create_command("git")?
             .args(&["reset", "--hard", "HEAD"])
             .current_dir(repo_dir.path())
             .output()?;
@@ -592,7 +625,7 @@ mod tests {
     fn shows_modified() -> io::Result<()> {
         let repo_dir = fixture_repo(FixtureProvider::Git)?;
 
-        create_modified(&repo_dir.path())?;
+        create_modified(repo_dir.path())?;
 
         let actual = ModuleRenderer::new("git_status")
             .path(&repo_dir.path())
@@ -607,7 +640,7 @@ mod tests {
     fn shows_modified_with_count() -> io::Result<()> {
         let repo_dir = fixture_repo(FixtureProvider::Git)?;
 
-        create_modified(&repo_dir.path())?;
+        create_modified(repo_dir.path())?;
 
         let actual = ModuleRenderer::new("git_status")
             .config(toml::toml! {
@@ -626,7 +659,7 @@ mod tests {
     fn shows_added() -> io::Result<()> {
         let repo_dir = fixture_repo(FixtureProvider::Git)?;
 
-        create_added(&repo_dir.path())?;
+        create_added(repo_dir.path())?;
 
         let actual = ModuleRenderer::new("git_status")
             .path(&repo_dir.path())
@@ -641,7 +674,7 @@ mod tests {
     fn shows_staged_file() -> io::Result<()> {
         let repo_dir = fixture_repo(FixtureProvider::Git)?;
 
-        create_staged(&repo_dir.path())?;
+        create_staged(repo_dir.path())?;
 
         let actual = ModuleRenderer::new("git_status")
             .path(&repo_dir.path())
@@ -656,7 +689,7 @@ mod tests {
     fn shows_staged_file_with_count() -> io::Result<()> {
         let repo_dir = fixture_repo(FixtureProvider::Git)?;
 
-        create_staged(&repo_dir.path())?;
+        create_staged(repo_dir.path())?;
 
         let actual = ModuleRenderer::new("git_status")
             .config(toml::toml! {
@@ -678,11 +711,26 @@ mod tests {
         repo_dir.close()
     }
 
+    #[test]
+    fn shows_staged_and_modified_file() -> io::Result<()> {
+        let repo_dir = fixture_repo(FixtureProvider::Git)?;
+
+        create_staged_and_modified(repo_dir.path())?;
+
+        let actual = ModuleRenderer::new("git_status")
+            .path(&repo_dir.path())
+            .collect();
+        let expected = format_output("!+");
+
+        assert_eq!(expected, actual);
+        repo_dir.close()
+    }
+
     #[test]
     fn shows_renamed_file() -> io::Result<()> {
         let repo_dir = fixture_repo(FixtureProvider::Git)?;
 
-        create_renamed(&repo_dir.path())?;
+        create_renamed(repo_dir.path())?;
 
         let actual = ModuleRenderer::new("git_status")
             .path(&repo_dir.path())
@@ -697,7 +745,7 @@ mod tests {
     fn shows_renamed_file_with_count() -> io::Result<()> {
         let repo_dir = fixture_repo(FixtureProvider::Git)?;
 
-        create_renamed(&repo_dir.path())?;
+        create_renamed(repo_dir.path())?;
 
         let actual = ModuleRenderer::new("git_status")
             .config(toml::toml! {
@@ -712,11 +760,26 @@ mod tests {
         repo_dir.close()
     }
 
+    #[test]
+    fn shows_renamed_and_modified_file() -> io::Result<()> {
+        let repo_dir = fixture_repo(FixtureProvider::Git)?;
+
+        create_renamed_and_modified(repo_dir.path())?;
+
+        let actual = ModuleRenderer::new("git_status")
+            .path(&repo_dir.path())
+            .collect();
+        let expected = format_output("»!");
+
+        assert_eq!(expected, actual);
+        repo_dir.close()
+    }
+
     #[test]
     fn shows_deleted_file() -> io::Result<()> {
         let repo_dir = fixture_repo(FixtureProvider::Git)?;
 
-        create_deleted(&repo_dir.path())?;
+        create_deleted(repo_dir.path())?;
 
         let actual = ModuleRenderer::new("git_status")
             .path(&repo_dir.path())
@@ -731,7 +794,7 @@ mod tests {
     fn shows_deleted_file_with_count() -> io::Result<()> {
         let repo_dir = fixture_repo(FixtureProvider::Git)?;
 
-        create_deleted(&repo_dir.path())?;
+        create_deleted(repo_dir.path())?;
 
         let actual = ModuleRenderer::new("git_status")
             .config(toml::toml! {
@@ -746,16 +809,31 @@ mod tests {
         repo_dir.close()
     }
 
+    #[test]
+    fn doesnt_show_ignored_file() -> io::Result<()> {
+        let repo_dir = fixture_repo(FixtureProvider::Git)?;
+
+        create_staged_and_ignored(repo_dir.path())?;
+
+        let actual = ModuleRenderer::new("git_status")
+            .path(&repo_dir.path())
+            .collect();
+        let expected = format_output("+");
+
+        assert_eq!(expected, actual);
+        repo_dir.close()
+    }
+
     #[test]
     fn worktree_in_different_dir() -> io::Result<()> {
         let worktree_dir = tempfile::tempdir()?;
         let repo_dir = fixture_repo(FixtureProvider::Git)?;
 
-        Command::new("git")
+        create_command("git")?
             .args(&[
-                "config",
-                "core.worktree",
-                &worktree_dir.path().to_string_lossy(),
+                OsStr::new("config"),
+                OsStr::new("core.worktree"),
+                worktree_dir.path().as_os_str(),
             ])
             .current_dir(repo_dir.path())
             .output()?;
@@ -781,11 +859,11 @@ mod tests {
         let repo_dir = fixture_repo(FixtureProvider::Git)?;
         File::create(repo_dir.path().join("a"))?.sync_all()?;
         File::create(repo_dir.path().join("b"))?.sync_all()?;
-        Command::new("git")
+        create_command("git")?
             .args(&["add", "--all"])
             .current_dir(&repo_dir.path())
             .output()?;
-        Command::new("git")
+        create_command("git")?
             .args(&["commit", "-m", "add new files", "--no-gpg-sign"])
             .current_dir(&repo_dir.path())
             .output()?;
@@ -814,7 +892,7 @@ mod tests {
     fn ahead(repo_dir: &Path) -> io::Result<()> {
         File::create(repo_dir.join("readme.md"))?.sync_all()?;
 
-        Command::new("git")
+        create_command("git")?
             .args(&["commit", "-am", "Update readme", "--no-gpg-sign"])
             .current_dir(&repo_dir)
             .output()?;
@@ -824,7 +902,7 @@ mod tests {
     }
 
     fn behind(repo_dir: &Path) -> io::Result<()> {
-        Command::new("git")
+        create_command("git")?
             .args(&["reset", "--hard", "HEAD^"])
             .current_dir(repo_dir)
             .output()?;
@@ -834,7 +912,7 @@ mod tests {
     }
 
     fn diverge(repo_dir: &Path) -> io::Result<()> {
-        Command::new("git")
+        create_command("git")?
             .args(&["reset", "--hard", "HEAD^"])
             .current_dir(repo_dir)
             .output()?;
@@ -842,7 +920,7 @@ mod tests {
 
         fs::write(repo_dir.join("Cargo.toml"), " ")?;
 
-        Command::new("git")
+        create_command("git")?
             .args(&["commit", "-am", "Update readme", "--no-gpg-sign"])
             .current_dir(repo_dir)
             .output()?;
@@ -852,7 +930,7 @@ mod tests {
     }
 
     fn create_conflict(repo_dir: &Path) -> io::Result<()> {
-        Command::new("git")
+        create_command("git")?
             .args(&["reset", "--hard", "HEAD^"])
             .current_dir(repo_dir)
             .output()?;
@@ -860,19 +938,19 @@ mod tests {
 
         fs::write(repo_dir.join("readme.md"), "# goodbye")?;
 
-        Command::new("git")
+        create_command("git")?
             .args(&["add", "."])
             .current_dir(repo_dir)
             .output()?;
         barrier();
 
-        Command::new("git")
+        create_command("git")?
             .args(&["commit", "-m", "Change readme", "--no-gpg-sign"])
             .current_dir(repo_dir)
             .output()?;
         barrier();
 
-        Command::new("git")
+        create_command("git")?
             .args(&["pull", "--rebase"])
             .current_dir(repo_dir)
             .output()?;
@@ -885,7 +963,7 @@ mod tests {
         File::create(repo_dir.join("readme.md"))?.sync_all()?;
         barrier();
 
-        Command::new("git")
+        create_command("git")?
             .args(&["stash", "--all"])
             .current_dir(repo_dir)
             .output()?;
@@ -903,7 +981,7 @@ mod tests {
     fn create_added(repo_dir: &Path) -> io::Result<()> {
         File::create(repo_dir.join("license"))?.sync_all()?;
 
-        Command::new("git")
+        create_command("git")?
             .args(&["add", "-A", "-N"])
             .current_dir(repo_dir)
             .output()?;
@@ -921,7 +999,7 @@ mod tests {
     fn create_staged(repo_dir: &Path) -> io::Result<()> {
         File::create(repo_dir.join("license"))?.sync_all()?;
 
-        Command::new("git")
+        create_command("git")?
             .args(&["add", "."])
             .current_dir(repo_dir)
             .output()?;
@@ -930,14 +1008,30 @@ mod tests {
         Ok(())
     }
 
+    fn create_staged_and_modified(repo_dir: &Path) -> io::Result<()> {
+        let mut file = File::create(repo_dir.join("readme.md"))?;
+        file.sync_all()?;
+
+        create_command("git")?
+            .args(&["add", "."])
+            .current_dir(repo_dir)
+            .output()?;
+        barrier();
+
+        writeln!(&mut file, "modified")?;
+        file.sync_all()?;
+
+        Ok(())
+    }
+
     fn create_renamed(repo_dir: &Path) -> io::Result<()> {
-        Command::new("git")
+        create_command("git")?
             .args(&["mv", "readme.md", "readme.md.bak"])
             .current_dir(repo_dir)
             .output()?;
         barrier();
 
-        Command::new("git")
+        create_command("git")?
             .args(&["add", "-A"])
             .current_dir(repo_dir)
             .output()?;
@@ -946,9 +1040,47 @@ mod tests {
         Ok(())
     }
 
+    fn create_renamed_and_modified(repo_dir: &Path) -> io::Result<()> {
+        create_command("git")?
+            .args(&["mv", "readme.md", "readme.md.bak"])
+            .current_dir(repo_dir)
+            .output()?;
+        barrier();
+
+        create_command("git")?
+            .args(&["add", "-A"])
+            .current_dir(repo_dir)
+            .output()?;
+        barrier();
+
+        let mut file = File::create(repo_dir.join("readme.md.bak"))?;
+        writeln!(&mut file, "modified")?;
+        file.sync_all()?;
+
+        Ok(())
+    }
+
     fn create_deleted(repo_dir: &Path) -> io::Result<()> {
         fs::remove_file(repo_dir.join("readme.md"))?;
 
         Ok(())
     }
+
+    fn create_staged_and_ignored(repo_dir: &Path) -> io::Result<()> {
+        let mut file = File::create(repo_dir.join(".gitignore"))?;
+        writeln!(&mut file, "ignored.txt")?;
+        file.sync_all()?;
+
+        create_command("git")?
+            .args(&["add", ".gitignore"])
+            .current_dir(repo_dir)
+            .output()?;
+        barrier();
+
+        let mut file = File::create(repo_dir.join("ignored.txt"))?;
+        writeln!(&mut file, "modified")?;
+        file.sync_all()?;
+
+        Ok(())
+    }
 }
