@@ -3,6 +3,7 @@ mod aws;
 mod character;
 mod cmake;
 mod cmd_duration;
+mod cobol;
 mod conda;
 mod crystal;
 pub(crate) mod custom;
@@ -15,6 +16,7 @@ mod elixir;
 mod elm;
 mod env_var;
 mod erlang;
+mod fill;
 mod gcloud;
 mod git_branch;
 mod git_commit;
@@ -85,6 +87,7 @@ pub fn handle<'a>(module: &str, context: &'a Context) -> Option<Module<'a>> {
             "character" => character::module(context),
             "cmake" => cmake::module(context),
             "cmd_duration" => cmd_duration::module(context),
+            "cobol" => cobol::module(context),
             "conda" => conda::module(context),
             "dart" => dart::module(context),
             "deno" => deno::module(context),
@@ -95,6 +98,7 @@ pub fn handle<'a>(module: &str, context: &'a Context) -> Option<Module<'a>> {
             "elm" => elm::module(context),
             "erlang" => erlang::module(context),
             "env_var" => env_var::module(context),
+            "fill" => fill::module(context),
             "gcloud" => gcloud::module(context),
             "git_branch" => git_branch::module(context),
             "git_commit" => git_commit::module(context),
@@ -169,6 +173,7 @@ pub fn description(module: &str) -> &'static str {
         }
         "cmake" => "The currently installed version of CMake",
         "cmd_duration" => "How long the last command took to execute",
+        "cobol" => "The currently installed version of COBOL/GNUCOBOL",
         "conda" => "The current conda environment, if $CONDA_DEFAULT_ENV is set",
         "crystal" => "The currently installed version of Crystal",
         "dart" => "The currently installed version of Dart",
@@ -176,8 +181,11 @@ pub fn description(module: &str) -> &'static str {
         "directory" => "The current working directory",
         "docker_context" => "The current docker context",
         "dotnet" => "The relevant version of the .NET Core SDK for the current directory",
+        "elixir" => "The currently installed versions of Elixir and OTP",
+        "elm" => "The currently installed version of Elm",
         "env_var" => "Displays the current value of a selected environment variable",
         "erlang" => "Current OTP version",
+        "fill" => "Fills the remaining space on the line with a pad string",
         "gcloud" => "The current GCP client configuration",
         "git_branch" => "The active branch of the repo in your current directory",
         "git_commit" => "The active commit (and tag if any) of the repo in your current directory",
@@ -206,22 +214,37 @@ pub fn description(module: &str) -> &'static str {
         "php" => "The currently installed version of PHP",
         "purescript" => "The currently installed version of PureScript",
         "python" => "The currently installed version of Python",
-        "rlang" => "The currently installed version of R",
         "red" => "The currently installed version of Red",
+        "rlang" => "The currently installed version of R",
         "ruby" => "The currently installed version of Ruby",
         "rust" => "The currently installed version of Rust",
         "scala" => "The currently installed version of Scala",
-        "swift" => "The currently installed version of Swift",
         "shell" => "The currently used shell indicator",
         "shlvl" => "The current value of SHLVL",
+        "singularity" => "The currently used Singularity image",
         "status" => "The status of the last command",
+        "swift" => "The currently installed version of Swift",
         "terraform" => "The currently selected terraform workspace and version",
         "time" => "The current local time",
         "username" => "The active user's username",
-        "vlang" => "The currently installed version of V",
         "vagrant" => "The currently installed version of Vagrant",
         "vcsh" => "The currently active VCSH repository",
+        "vlang" => "The currently installed version of V",
         "zig" => "The currently installed version of Zig",
         _ => "<no description>",
     }
 }
+
+#[cfg(test)]
+mod test {
+    use super::*;
+    use crate::module::ALL_MODULES;
+
+    #[test]
+    fn all_modules_have_description() {
+        for module in ALL_MODULES {
+            println!("Checking if {:?} has a description", module);
+            assert_ne!(description(module), "<no description>");
+        }
+    }
+}
